require 'spec_helper'

describe 'RandTest::Strings' do

  let(:min) { 10 }
  let(:max) { 100 }

  describe "using no modification options" do

    shared_examples "string generation with no options" do
      it "generates an string of length between min and max" do
        expect(string.length).to satisfy { |length| ((min <= length) && ( length <= max )) }
      end
    end

    context "#ascii_string" do
      it_behaves_like "string generation with no options" do
        subject(:string) { random_ascii_of_length_between(min,max) }
      end
    end

    context "#unicode_string" do
      it_behaves_like "string generation with no options" do
        subject(:string) { random_unicode_of_length(min,max) }
      end
    end

  end

  describe "requesting an string with spaces" do

    let(:options) { {:spaces => true} }

    shared_examples "string generation with spaces" do

      let(:num_spaces) { string.chars.inject(0) { |a,v| if (v!=" ") then a+=1 else a end } }

      it "generates an string of length between min and max" do
        expect(string.length).to satisfy { |length| ((min <= length) && ( length <= (max+num_spaces) )) }
      end

      it "generate a sentence with spaces" do
        expect(num_spaces).to be > 0
      end
    end

    context "#ascii_string" do
      it_behaves_like "string generation with spaces" do
        subject(:string) { random_ascii_of_length_between(min, max, options) }
      end
    end

    context "#unicode_string" do
      it_behaves_like "string generation with spaces" do
        subject(:string) { random_unicode_of_length(min, max, options) }
      end
    end
  end
end
